/*
 * Closes file descriptor fd. Exiting or terminating a process implicitly closes
 * all its open file descriptors, as if by calling this function for each one.
 *
 * Authored by Alex Stratford
 */

#include "system_calls.h"
#include <stddef.h> // Dependency for NULL
#include "threads/interrupt.h" // Dependency for intr_frame struct
#include "filesys/file.h" // Dependency for file_close
#include "threads/malloc.h" // Dependency for free
#include "lib/kernel/list.h" // Dependency for list_remove

void syscall_close(struct intr_frame *f) {
	// pop off first int argument from interrupt frame
	int file_descriptor = *((int*)f->esp + 1);
	// Get file associated with file_descriptor
	struct file *file = get_associated_file_pointer(file_descriptor);
	if (file == NULL) { // Checking if file is empty or non-existent
		f->eax = -1; // Returning a failure state
		return;
	}
	// Close the file using file_close, defined in file.h
	file_close(file);
	// Remove the file_descriptor
	disassociate_file_descriptor(file_descriptor);
}
